@@ -1,16 +1,15 @@
 import os.path
-from typing import Any, Dict, List, Set, Tuple
+from typing import Set
+
 from docutils.nodes import Node
-from sphinx.application import Sphinx
 from sphinx.builders import Builder
 from sphinx.locale import __
-
 from sphinx.util import logging
-logger = logging.getLogger(__name__)
-
 
 from .postprocess import postprocess
 
+logger = logging.getLogger(__name__)
+
 
 class ProbsSystemRDFBuilder(Builder):
     """
@@ -24,6 +23,7 @@ class ProbsSystemRDFBuilder(Builder):
         return ''
 
     def get_outdated_docs(self) -> Set[str]:
+        assert self.env
         return self.env.found_docs
 
     def prepare_writing(self, docnames: Set[str]) -> None:
@@ -33,10 +33,11 @@ class ProbsSystemRDFBuilder(Builder):
         return
 
     def finish(self) -> None:
+        assert self.app.builder
         env = self.app.builder.env
         filename = os.path.join(self.outdir, 'output.ttl')
         if hasattr(env, 'probs_graph'):
-            graph = env.probs_graph
+            graph = env.probs_graph  # type: ignore
             postprocess(graph)
             with open(filename, 'wb') as f:
                 graph.serialize(f, format="turtle")
